/* vm-creator.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from vm-creator.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <float.h>
#include <math.h>
#include <osinfo/osinfo.h>
#include <config.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesVMCreatorPrivate BoxesVMCreatorPrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_TYPE_COLLECTION_SOURCE (boxes_collection_source_get_type ())
#define BOXES_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSource))
#define BOXES_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))
#define BOXES_IS_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_IS_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_COLLECTION_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))

typedef struct _BoxesCollectionSource BoxesCollectionSource;
typedef struct _BoxesCollectionSourceClass BoxesCollectionSourceClass;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block33Data Block33Data;
typedef struct _Block34Data Block34Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesVmCreatorCreateVmData BoxesVmCreatorCreateVmData;
typedef struct _Block35Data Block35Data;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _Block36Data Block36Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData BoxesVmCreatorCreateDomainNameAndTitleFromMediaData;
typedef struct _BoxesVmCreatorCreateTargetVolumeData BoxesVmCreatorCreateTargetVolumeData;
typedef struct _BoxesVmCreatorGetStoragePoolData BoxesVmCreatorGetStoragePoolData;
typedef struct _BoxesParamSpecVMCreator BoxesParamSpecVMCreator;

struct _BoxesVMCreator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesVMCreatorPrivate * priv;
};

struct _BoxesVMCreatorClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesVMCreator *self);
};

struct _BoxesVMCreatorPrivate {
	BoxesInstallerMedia* _install_media;
	gulong state_changed_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesMachineActor* machine_actor;
	BoxesCollectionSource* source;
	BoxesDisplayConfig* config;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	gchar* (*get_screenshot_prefix) (BoxesMachine* self);
	void (*connect_display) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	GVirDomain* domain;
	GVirConfigDomain* domain_config;
	GVirConnection* connection;
	BoxesVMCreator* vm_creator;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _Block33Data {
	int _ref_count_;
	BoxesVMCreator * self;
	gpointer _async_data_;
};

struct _Block34Data {
	int _ref_count_;
	Block33Data * _data33_;
	gulong handler;
};

typedef enum  {
	UNATTENDED_INSTALLER_ERROR_SETUP_INCOMPLETE
} UnattendedInstallerError;
#define UNATTENDED_INSTALLER_ERROR unattended_installer_error_quark ()
struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_spice_config) (BoxesInstallerMedia* self, GVirConfigDomainGraphicsSpice* graphics);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkVBox* setup_vbox);
	void (*check_needed_info) (BoxesInstallerMedia* self, GError** error);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
};

typedef enum  {
	BOXES_VM_CONFIGURATOR_ERROR_NO_GUEST_CAPS
} BoxesVMConfiguratorError;
#define BOXES_VM_CONFIGURATOR_ERROR boxes_vm_configurator_error_quark ()
struct _BoxesVmCreatorCreateVmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* result;
	Block33Data* _data33_;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	Block34Data* _data34_;
	BoxesApp* _tmp2_;
	gulong _tmp3_;
	gchar* title;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* name;
	BoxesInstallerMedia* _tmp6_;
	const gchar* _tmp7_;
	GCancellable* _tmp8_;
	const gchar* _tmp9_;
	BoxesInstallerMedia* _tmp10_;
	OsinfoResources* _tmp11_;
	gint64 _tmp12_;
	gint64 _tmp13_;
	GVirStorageVol* _tmp14_;
	GVirStorageVol* volume;
	GVirConnection* _tmp15_;
	GVirConnection* _tmp16_;
	GCancellable* _tmp17_;
	GVirConfigCapabilities* _tmp18_;
	GVirConfigCapabilities* caps;
	GVirStorageVol* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	GVirConfigCapabilities* _tmp23_;
	GVirConfigDomain* _tmp24_;
	GVirConfigDomain* config;
	GVirConfigDomain* _tmp25_;
	const gchar* _tmp26_;
	GVirConfigDomain* _tmp27_;
	const gchar* _tmp28_;
	GVirConnection* _tmp29_;
	GVirConnection* _tmp30_;
	GVirConfigDomain* _tmp31_;
	GVirDomain* _tmp32_;
	GVirDomain* domain;
	BoxesApp* _tmp33_;
	BoxesApp* _tmp34_;
	BoxesCollectionSource* _tmp35_;
	BoxesCollectionSource* _tmp36_;
	BoxesApp* _tmp37_;
	GVirConnection* _tmp38_;
	GVirConnection* _tmp39_;
	GVirDomain* _tmp40_;
	BoxesLibvirtMachine* _tmp41_;
	BoxesLibvirtMachine* _tmp42_;
	GError * _inner_error_;
};

struct _Block35Data {
	int _ref_count_;
	BoxesVMCreator * self;
	BoxesLibvirtMachine* machine;
};

struct _Block36Data {
	int _ref_count_;
	Block35Data * _data35_;
	gulong signal_id;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED
} BoxesMachineMachineState;

struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* title;
	gchar* result;
	BoxesInstallerMedia* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* base_title;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	OsinfoOs* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* base_name;
	BoxesInstallerMedia* _tmp15_;
	gboolean _tmp16_;
	gboolean _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* name;
	GVirStoragePool* _tmp22_;
	GVirStoragePool* pool;
	gint i;
	gboolean _tmp23_;
	gboolean _tmp24_;
	gint _tmp25_;
	gboolean _tmp26_;
	gboolean _tmp27_;
	GVirConnection* _tmp28_;
	GVirConnection* _tmp29_;
	const gchar* _tmp30_;
	GVirDomain* _tmp31_;
	GVirDomain* _tmp32_;
	gboolean _tmp33_;
	GVirConnection* _tmp34_;
	GVirConnection* _tmp35_;
	const gchar* _tmp36_;
	GVirDomain* _tmp37_;
	GVirDomain* _tmp38_;
	gboolean _tmp39_;
	const gchar* _tmp40_;
	GVirStorageVol* _tmp41_;
	GVirStorageVol* _tmp42_;
	gboolean _tmp43_;
	const gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gint _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	const gchar* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	gint _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateTargetVolumeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gint64 storage;
	GVirStorageVol* result;
	GVirStoragePool* _tmp0_;
	GVirStoragePool* pool;
	const gchar* _tmp1_;
	gint64 _tmp2_;
	GVirConfigStorageVol* _tmp3_;
	GVirConfigStorageVol* config;
	GVirStoragePool* _tmp4_;
	GVirConfigStorageVol* _tmp5_;
	GVirStorageVol* _tmp6_;
	GVirStorageVol* volume;
	GError * _inner_error_;
};

struct _BoxesVmCreatorGetStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GVirStoragePool* result;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirStoragePool* _tmp2_;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp3_;
	GVirConfigStoragePool* _tmp4_;
	GVirConfigStoragePool* config;
	GVirConnection* _tmp5_;
	GVirConnection* _tmp6_;
	GVirConfigStoragePool* _tmp7_;
	GVirStoragePool* _tmp8_;
	GVirStoragePool* _tmp9_;
	GVirStoragePool* _tmp10_;
	GVirStoragePool* _tmp11_;
	GVirStoragePool* _tmp12_;
	GError * _inner_error_;
};

struct _BoxesParamSpecVMCreator {
	GParamSpec parent_instance;
};


static gpointer boxes_vm_creator_parent_class = NULL;
extern BoxesApp* boxes_app_app;

gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_VM_CREATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorPrivate))
enum  {
	BOXES_VM_CREATOR_DUMMY_PROPERTY
};
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
static void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec);
static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_collection_source_get_type (void) G_GNUC_CONST;
GType boxes_display_config_get_type (void) G_GNUC_CONST;
static void boxes_vm_creator_create_vm_data_free (gpointer _data);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_);
static Block33Data* block33_data_ref (Block33Data* _data33_);
static void block33_data_unref (void * _userdata_);
static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self);
static Block34Data* block34_data_ref (Block34Data* _data34_);
static void block34_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void ___lambda51_ (Block34Data* _data34_);
static void ____lambda51__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gchar* boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** title, GError** error);
static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
GQuark unattended_installer_error_quark (void);
GQuark boxes_vm_configurator_error_quark (void);
GVirConfigDomain* boxes_vm_configurator_create_domain_config (BoxesInstallerMedia* install_media, const gchar* target_path, GVirConfigCapabilities* caps, GError** error);
BoxesLibvirtMachine* boxes_app_add_domain (BoxesApp* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_installer_get_express_install (BoxesUnattendedInstaller* self);
static Block36Data* block36_data_ref (Block36Data* _data36_);
static void block36_data_unref (void * _userdata_);
static void ___lambda52_ (Block36Data* _data36_);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
gboolean boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static void ____lambda52__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain, GVirStoragePool** pool);
static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, GVirStorageVol* volume);
static void boxes_vm_creator_mark_as_installed (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_vm_configurator_post_install_setup (GVirConfigDomain* domain);
void boxes_vm_configurator_mark_as_installed (GVirConfigDomain* domain);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
static void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_create_target_volume_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_);
static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigStorageVol* boxes_vm_configurator_create_volume_config (const gchar* name, gint64 storage, GError** error);
static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data);
static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_);
GVirConfigStoragePool* boxes_vm_configurator_get_pool_config (GError** error);
static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_finalize (BoxesVMCreator* obj);


BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media) {
	BoxesVMCreator* self = NULL;
	BoxesInstallerMedia* _tmp0_;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (install_media != NULL, NULL);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = install_media;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (self, _tmp0_);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return self;
#line 652 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media) {
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct (BOXES_TYPE_VM_CREATOR, install_media);
#line 659 "vm-creator.c"
}


static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (self, _sender, pspec);
#line 666 "vm-creator.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 673 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesVMCreator* self = NULL;
	BoxesLibvirtMachine* _tmp0_;
	gulong _tmp1_ = 0UL;
	BoxesLibvirtMachine* _tmp2_;
	BoxesVMCreator* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = g_signal_connect ((GObject*) _tmp0_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp1_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = machine;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _boxes_vm_creator_ref0 (self);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_tmp2_->vm_creator);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_->vm_creator = _tmp3_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = machine;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (self, (GObject*) _tmp4_, NULL);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return self;
#line 708 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine) {
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct_for_install_completion (BOXES_TYPE_VM_CREATOR, machine);
#line 715 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_data_free (gpointer _data) {
	BoxesVmCreatorCreateVmData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateVmData, _data_);
#line 730 "vm-creator.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return self ? g_object_ref (self) : NULL;
#line 737 "vm-creator.c"
}


void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
	BoxesVMCreator* _tmp0_;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateVmData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_vm_creator_create_vm);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_vm_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = cancellable;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 764 "vm-creator.c"
}


BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesVmCreatorCreateVmData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 775 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 785 "vm-creator.c"
}


static Block33Data* block33_data_ref (Block33Data* _data33_) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data33_->_ref_count_);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return _data33_;
#line 794 "vm-creator.c"
}


static void block33_data_unref (void * _userdata_) {
	Block33Data* _data33_;
	_data33_ = (Block33Data*) _userdata_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data33_->_ref_count_)) {
#line 803 "vm-creator.c"
		BoxesVMCreator * self;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		self = _data33_->self;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block33Data, _data33_);
#line 811 "vm-creator.c"
	}
}


static Block34Data* block34_data_ref (Block34Data* _data34_) {
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data34_->_ref_count_);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return _data34_;
#line 821 "vm-creator.c"
}


static void block34_data_unref (void * _userdata_) {
	Block34Data* _data34_;
	_data34_ = (Block34Data*) _userdata_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data34_->_ref_count_)) {
#line 830 "vm-creator.c"
		BoxesVMCreator * self;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		self = _data34_->_data33_->self;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data34_->_data33_);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data34_->_data33_ = NULL;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block34Data, _data34_);
#line 840 "vm-creator.c"
	}
}


static void ___lambda51_ (Block34Data* _data34_) {
	Block33Data* _data33_;
	BoxesVMCreator * self;
	BoxesApp* _tmp0_;
	gulong _tmp1_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data33_ = _data34_->_data33_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self = _data33_->self;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data33_->_async_data_);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data34_->handler;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 862 "vm-creator.c"
}


static void ____lambda51__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	___lambda51_ (self);
#line 869 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 883 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 892 "vm-creator.c"
		goto _state_0;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 896 "vm-creator.c"
		goto _state_1;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 900 "vm-creator.c"
		goto _state_2;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 904 "vm-creator.c"
		goto _state_3;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 908 "vm-creator.c"
		goto _state_4;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 912 "vm-creator.c"
		goto _state_5;
		default:
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 917 "vm-creator.c"
	}
	_state_0:
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_ = g_slice_new0 (Block33Data);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_->_ref_count_ = 1;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_->self = boxes_vm_creator_ref (_data_->self);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_->_async_data_ = _data_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp1_ == NULL) {
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_ = g_slice_new0 (Block34Data);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_->_ref_count_ = 1;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_->_data33_ = block33_data_ref (_data_->_data33_);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_->handler = (gulong) 0;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = boxes_app_app;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = 0UL;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = g_signal_connect_data ((GObject*) _data_->_tmp2_, "notify::default-connection", (GCallback) ____lambda51__g_object_notify, block34_data_ref (_data_->_data34_), (GClosureNotify) block34_data_unref, 0);
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_->handler = _data_->_tmp3_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 954 "vm-creator.c"
		_state_1:
		;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block34_data_unref (_data_->_data34_);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data34_ = NULL;
#line 961 "vm-creator.c"
	}
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 2;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media (_data_->self, boxes_vm_creator_create_vm_ready, _data_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 971 "vm-creator.c"
	_state_2:
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = boxes_vm_creator_create_domain_name_and_title_from_media_finish (_data_->self, _data_->_res_, &_data_->_tmp4_, &_data_->_inner_error_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp4_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp5_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 999 "vm-creator.c"
		} else {
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1003 "vm-creator.c"
		}
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1009 "vm-creator.c"
	}
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->self->priv->_install_media;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->name;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->cancellable;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 3;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_for_installation (_data_->_tmp6_, _data_->_tmp7_, _data_->_tmp8_, boxes_vm_creator_create_vm_ready, _data_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1023 "vm-creator.c"
	_state_3:
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_for_installation_finish (_data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1045 "vm-creator.c"
		} else {
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1049 "vm-creator.c"
		}
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1055 "vm-creator.c"
	}
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->name;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->self->priv->_install_media;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->_tmp10_->resources;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = osinfo_resources_get_storage (_data_->_tmp11_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 4;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume (_data_->self, _data_->_tmp9_, _data_->_tmp13_, boxes_vm_creator_create_vm_ready, _data_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1073 "vm-creator.c"
	_state_4:
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = boxes_vm_creator_create_target_volume_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp14_;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1099 "vm-creator.c"
		} else {
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1103 "vm-creator.c"
		}
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1109 "vm-creator.c"
	}
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = boxes_vm_creator_get_connection (_data_->self);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp17_ = _data_->cancellable;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 5;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	gvir_connection_get_capabilities_async (_data_->_tmp16_, _data_->_tmp17_, boxes_vm_creator_create_vm_ready, _data_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1123 "vm-creator.c"
	_state_5:
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = NULL;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = gvir_connection_get_capabilities_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->caps = _data_->_tmp18_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1151 "vm-creator.c"
		} else {
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1155 "vm-creator.c"
		}
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1161 "vm-creator.c"
	}
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->volume;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = NULL;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = gvir_storage_vol_get_path (_data_->_tmp19_, &_data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = _data_->_tmp20_;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1193 "vm-creator.c"
		} else {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1197 "vm-creator.c"
		}
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1203 "vm-creator.c"
	}
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = _data_->self->priv->_install_media;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = _data_->caps;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = NULL;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = boxes_vm_configurator_create_domain_config (_data_->_tmp22_, _data_->_tmp21_, _data_->_tmp23_, &_data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp24_;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1237 "vm-creator.c"
		} else {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1241 "vm-creator.c"
		}
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1247 "vm-creator.c"
	}
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = _data_->config;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = _data_->name;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_name (_data_->_tmp25_, _data_->_tmp26_);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = _data_->config;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->title;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_title (_data_->_tmp27_, _data_->_tmp28_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = boxes_vm_creator_get_connection (_data_->self);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = _data_->config;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = gvir_connection_create_domain (_data_->_tmp30_, _data_->_tmp31_, &_data_->_inner_error_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->domain = _data_->_tmp32_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1297 "vm-creator.c"
		} else {
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1301 "vm-creator.c"
		}
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1307 "vm-creator.c"
	}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = boxes_app_app;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = boxes_app_app;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = boxes_app_get_default_source (_data_->_tmp34_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->_tmp35_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = boxes_app_app;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = boxes_app_get_default_connection (_data_->_tmp37_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = _data_->domain;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = NULL;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = boxes_app_add_domain (_data_->_tmp33_, _data_->_tmp36_, _data_->_tmp39_, _data_->_tmp40_, &_data_->_inner_error_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = _data_->_tmp41_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->domain);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block33_data_unref (_data_->_data33_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_data33_ = NULL;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1357 "vm-creator.c"
		} else {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1361 "vm-creator.c"
		}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1367 "vm-creator.c"
	}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->_tmp42_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	block33_data_unref (_data_->_data33_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_ = NULL;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1391 "vm-creator.c"
	} else {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1395 "vm-creator.c"
	}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	block33_data_unref (_data_->_data33_);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_data33_ = NULL;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1421 "vm-creator.c"
	} else {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1425 "vm-creator.c"
	}
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1431 "vm-creator.c"
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data35_->_ref_count_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return _data35_;
#line 1440 "vm-creator.c"
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
#line 1449 "vm-creator.c"
		BoxesVMCreator * self;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		self = _data35_->self;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data35_->machine);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block35Data, _data35_);
#line 1459 "vm-creator.c"
	}
}


static Block36Data* block36_data_ref (Block36Data* _data36_) {
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data36_->_ref_count_);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return _data36_;
#line 1469 "vm-creator.c"
}


static void block36_data_unref (void * _userdata_) {
	Block36Data* _data36_;
	_data36_ = (Block36Data*) _userdata_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data36_->_ref_count_)) {
#line 1478 "vm-creator.c"
		BoxesVMCreator * self;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		self = _data36_->_data35_->self;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block35_data_unref (_data36_->_data35_);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_->_data35_ = NULL;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block36Data, _data36_);
#line 1488 "vm-creator.c"
	}
}


static void ___lambda52_ (Block36Data* _data36_) {
	Block35Data* _data35_;
	BoxesVMCreator * self;
	BoxesApp* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	BoxesApp* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	BoxesApp* _tmp5_;
	BoxesApp* _tmp6_;
	gulong _tmp7_;
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_ = _data36_->_data35_;
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self = _data35_->self;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 1518 "vm-creator.c"
	}
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_app_app;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data35_->machine;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_app_select_item (_tmp3_, (BoxesCollectionItem*) _tmp4_);
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_app_app;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_app_set_fullscreen (_tmp5_, TRUE);
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = boxes_app_app;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _data36_->signal_id;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp6_, _tmp7_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return;
#line 1538 "vm-creator.c"
}


static void ____lambda52__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	___lambda52_ (self);
#line 1545 "vm-creator.c"
}


void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
	Block35Data* _data35_;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_ = FALSE;
	BoxesInstallerMedia* _tmp3_;
	gboolean _tmp7_;
	BoxesLibvirtMachine* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	gulong _tmp14_ = 0UL;
	BoxesLibvirtMachine* _tmp15_;
	BoxesVMCreator* _tmp16_;
	GError * _inner_error_ = NULL;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_ = g_slice_new0 (Block35Data);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_->_ref_count_ = 1;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_->self = boxes_vm_creator_ref (self);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_->machine = _tmp1_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = TRUE;
#line 1584 "vm-creator.c"
	} else {
		BoxesInstallerMedia* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = self->priv->_install_media;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = boxes_unattended_installer_get_express_install (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp4_) : NULL);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = !_tmp6_;
#line 1597 "vm-creator.c"
	}
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _tmp2_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp7_) {
#line 1603 "vm-creator.c"
		Block36Data* _data36_;
		BoxesApp* _tmp8_;
		gulong _tmp9_ = 0UL;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_ = g_slice_new0 (Block36Data);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_->_ref_count_ = 1;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_->_data35_ = block35_data_ref (_data35_);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_->signal_id = (gulong) 0;
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = boxes_app_app;
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_signal_connect_data ((GObject*) _tmp8_, "notify::ui-state", (GCallback) ____lambda52__g_object_notify, block36_data_ref (_data36_), (GClosureNotify) block36_data_unref, 0);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_->signal_id = _tmp9_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		block36_data_unref (_data36_);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data36_ = NULL;
#line 1625 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp10_;
		GVirDomain* _tmp11_;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data35_->machine;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_->domain;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_domain_start (_tmp11_, (guint) 0, &_inner_error_);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_propagate_error (error, _inner_error_);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			block35_data_unref (_data35_);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_data35_ = NULL;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return;
#line 1645 "vm-creator.c"
		}
	}
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp12_ = _data35_->machine;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_post_install_config (self, _tmp12_);
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = _data35_->machine;
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = g_signal_connect ((GObject*) _tmp13_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp14_;
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _data35_->machine;
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = _boxes_vm_creator_ref0 (self);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_tmp15_->vm_creator);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp15_->vm_creator = _tmp16_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	block35_data_unref (_data35_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data35_ = NULL;
#line 1670 "vm-creator.c"
}


static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec) {
	GObject* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* machine;
	gboolean _tmp2_ = FALSE;
	BoxesLibvirtMachine* _tmp3_;
	BoxesMachineMachineState _tmp4_;
	BoxesMachineMachineState _tmp5_;
	gboolean _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	GVirDomain* _tmp11_;
	GVirDomain* _tmp12_;
	GVirDomain* domain;
	BoxesLibvirtMachine* _tmp13_;
	gboolean _tmp14_;
	GVirDomain* _tmp20_;
	gboolean _tmp21_ = FALSE;
	GVirConnection* _tmp29_;
	GVirConnection* _tmp30_;
	GVirDomain* _tmp31_;
	GVirStorageVol* _tmp32_ = NULL;
	GVirStorageVol* volume;
	GVirStorageVol* _tmp33_;
	gboolean _tmp34_ = FALSE;
	GError * _inner_error_ = NULL;
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (object != NULL);
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = object;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL);
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	machine = _tmp1_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = machine;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_machine_get_state ((BoxesMachine*) _tmp3_);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp5_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 1717 "vm-creator.c"
		BoxesLibvirtMachine* _tmp6_;
		BoxesMachineMachineState _tmp7_;
		BoxesMachineMachineState _tmp8_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = machine;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = boxes_machine_get_state ((BoxesMachine*) _tmp6_);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _tmp7_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = _tmp8_ != BOXES_MACHINE_MACHINE_STATE_UNKNOWN;
#line 1729 "vm-creator.c"
	} else {
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = FALSE;
#line 1733 "vm-creator.c"
	}
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp9_ = _tmp2_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp9_) {
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 1743 "vm-creator.c"
	}
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp10_ = machine;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp11_ = _tmp10_->domain;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	domain = _tmp12_;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = machine;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = ((BoxesMachine*) _tmp13_)->deleted;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp14_) {
#line 1759 "vm-creator.c"
		BoxesLibvirtMachine* _tmp15_;
		gulong _tmp16_;
		BoxesLibvirtMachine* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = machine;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = self->priv->state_changed_id;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp15_, _tmp16_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = machine;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp17_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp19_ = _tmp18_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:83: '%s' was deleted, no need for post-installation se" \
"tup on it", _tmp19_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 1785 "vm-creator.c"
	}
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp20_ = domain;
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp21_ = gvir_domain_get_saved (_tmp20_);
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp21_) {
#line 1793 "vm-creator.c"
		BoxesLibvirtMachine* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
		BoxesLibvirtMachine* _tmp25_;
		GVirConfigDomain* _tmp26_;
		gboolean _tmp27_ = FALSE;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp22_ = machine;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp23_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp22_);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = _tmp23_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:88: '%s' has saved state, no need for post-installatio" \
"n setup on it", _tmp24_);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = machine;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _tmp25_->domain_config;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = boxes_vm_configurator_is_install_config (_tmp26_);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_tmp27_) {
#line 1816 "vm-creator.c"
			GVirDomain* _tmp28_;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp28_ = domain;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_async (_tmp28_, (guint) 0, NULL, NULL, NULL);
#line 1822 "vm-creator.c"
		}
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (machine);
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 1830 "vm-creator.c"
	}
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp29_ = boxes_vm_creator_get_connection (self);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp30_ = _tmp29_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp31_ = domain;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp32_ = boxes_get_storage_volume (_tmp30_, _tmp31_, NULL);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	volume = _tmp32_;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp33_ = volume;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp34_ = boxes_vm_creator_guest_installed_os (self, _tmp33_);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_tmp34_) {
#line 1848 "vm-creator.c"
		BoxesLibvirtMachine* _tmp35_;
		BoxesLibvirtMachine* _tmp41_;
		gulong _tmp42_;
		BoxesLibvirtMachine* _tmp43_;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp35_ = machine;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_mark_as_installed (self, _tmp35_);
#line 1857 "vm-creator.c"
		{
			GVirDomain* _tmp36_;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp36_ = domain;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start (_tmp36_, (guint) 0, &_inner_error_);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_inner_error_ != NULL) {
#line 1866 "vm-creator.c"
				goto __catch66_g_error;
			}
		}
		goto __finally66;
		__catch66_g_error:
		{
			GError* _error_ = NULL;
			GVirDomain* _tmp37_;
			const gchar* _tmp38_ = NULL;
			GError* _tmp39_;
			const gchar* _tmp40_;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_error_ = _inner_error_;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_inner_error_ = NULL;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp37_ = domain;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp38_ = gvir_domain_get_name (_tmp37_);
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp39_ = _error_;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_tmp40_ = _tmp39_->message;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:104: Failed to start domain '%s': %s", _tmp38_, _tmp40_);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_error_);
#line 1894 "vm-creator.c"
		}
		__finally66:
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (machine);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_inner_error_);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return;
#line 1911 "vm-creator.c"
		}
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp41_ = machine;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp42_ = self->priv->state_changed_id;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp41_, _tmp42_);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp43_ = machine;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (_tmp43_->vm_creator);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp43_->vm_creator = NULL;
#line 1925 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp44_;
		GVirConfigDomain* _tmp45_;
		gboolean _tmp46_ = FALSE;
		BoxesLibvirtMachine* _tmp47_;
		gulong _tmp48_;
		BoxesApp* _tmp49_;
		BoxesLibvirtMachine* _tmp50_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp44_ = machine;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp45_ = _tmp44_->domain_config;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp46_ = boxes_vm_configurator_is_live_config (_tmp45_);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (!_tmp46_) {
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (machine);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return;
#line 1950 "vm-creator.c"
		}
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp47_ = machine;
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp48_ = self->priv->state_changed_id;
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp47_, _tmp48_);
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp49_ = boxes_app_app;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp50_ = machine;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_app_delete_machine (_tmp49_, (BoxesMachine*) _tmp50_, TRUE);
#line 1964 "vm-creator.c"
	}
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (volume);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (domain);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (machine);
#line 1972 "vm-creator.c"
}


static void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:119: Setting post-installation configuration on '%s'", _tmp2_);
#line 1993 "vm-creator.c"
	{
		BoxesLibvirtMachine* _tmp3_;
		GVirConfigDomain* _tmp4_;
		gchar* _tmp5_ = NULL;
		gchar* config_xml;
		const gchar* _tmp6_;
		GVirConfigDomain* _tmp7_;
		GVirConfigDomain* post_install_config;
		GVirConfigDomain* _tmp8_;
		BoxesLibvirtMachine* _tmp9_;
		GVirDomain* _tmp10_;
		GVirConfigDomain* _tmp11_;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = machine;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = _tmp3_->domain_config;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = gvir_config_object_to_xml ((GVirConfigObject*) _tmp4_);
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		config_xml = _tmp5_;
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = config_xml;
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = gvir_config_domain_new_from_xml (_tmp6_, &_inner_error_);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		post_install_config = _tmp7_;
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_free0 (config_xml);
#line 2024 "vm-creator.c"
			goto __catch67_g_error;
		}
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = post_install_config;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_post_install_setup (_tmp8_);
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_->domain;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = post_install_config;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (post_install_config);
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_free0 (config_xml);
#line 2045 "vm-creator.c"
			goto __catch67_g_error;
		}
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (post_install_config);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (config_xml);
#line 2052 "vm-creator.c"
	}
	goto __finally67;
	__catch67_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _error_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_->message;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:128: Failed to set post-install configuration on '%s' " \
"failed: %s", _tmp14_, _tmp16_);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 2081 "vm-creator.c"
	}
	__finally67:
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 2092 "vm-creator.c"
	}
}


static void boxes_vm_creator_mark_as_installed (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	BoxesMachineMachineState _tmp4_;
	BoxesMachineMachineState _tmp5_;
	BoxesLibvirtMachine* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	GError * _inner_error_ = NULL;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_machine_get_state ((BoxesMachine*) _tmp0_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = machine;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_machine_get_state ((BoxesMachine*) _tmp3_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail ((_tmp2_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) || (_tmp5_ == BOXES_MACHINE_MACHINE_STATE_UNKNOWN));
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = machine;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp6_);
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _tmp7_;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:134: Marking '%s' as installed.", _tmp8_);
#line 2134 "vm-creator.c"
	{
		BoxesLibvirtMachine* _tmp9_;
		GVirConfigDomain* _tmp10_;
		BoxesLibvirtMachine* _tmp11_;
		GVirDomain* _tmp12_;
		BoxesLibvirtMachine* _tmp13_;
		GVirConfigDomain* _tmp14_;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_->domain_config;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_mark_as_installed (_tmp10_);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = machine;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _tmp11_->domain;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = machine;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_->domain_config;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp12_, _tmp14_, &_inner_error_);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 2160 "vm-creator.c"
			goto __catch68_g_error;
		}
	}
	goto __finally68;
	__catch68_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		GError* _tmp18_;
		const gchar* _tmp19_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = machine;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp15_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = _tmp16_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = _error_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp19_ = _tmp18_->message;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:139: Failed to marking domain '%s' as installed: %s", _tmp17_, _tmp19_);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 2191 "vm-creator.c"
	}
	__finally68:
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_inner_error_ != NULL) {
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return;
#line 2202 "vm-creator.c"
	}
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 2210 "vm-creator.c"
}


static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, GVirStorageVol* volume) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (volume != NULL, FALSE);
#line 2221 "vm-creator.c"
	{
		GVirStorageVol* _tmp0_;
		GVirStorageVolInfo* _tmp1_ = NULL;
		GVirStorageVolInfo* info;
		guint64 _tmp2_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp0_ = volume;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = gvir_storage_vol_get_info (_tmp0_, &_inner_error_);
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		info = _tmp1_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_inner_error_ != NULL) {
#line 2235 "vm-creator.c"
			goto __catch69_g_error;
		}
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = info->allocation;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		result = _tmp2_ >= ((guint64) OSINFO_MEBIBYTES);
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		__vala_GVirStorageVolInfo_free0 (info);
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return result;
#line 2246 "vm-creator.c"
	}
	goto __finally69;
	__catch69_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp3_;
		const gchar* _tmp4_ = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = volume;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = gvir_storage_vol_get_name (_tmp3_);
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _error_;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_->message;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:150: Failed to get information from volume '%s': %s", _tmp4_, _tmp6_);
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return result;
#line 2276 "vm-creator.c"
	}
	__finally69:
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_clear_error (&_inner_error_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2285 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->result);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData, _data_);
#line 2298 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	BoxesVMCreator* _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_vm_creator_create_domain_name_and_title_from_media);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_domain_name_and_title_from_media_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 2317 "vm-creator.c"
}


static gchar* boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** title, GError** error) {
	gchar* result;
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 2328 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (title) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		*title = _data_->title;
#line 2336 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 2340 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->title = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 2350 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 2364 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_) {
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2373 "vm-creator.c"
		goto _state_0;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2377 "vm-creator.c"
		goto _state_1;
		default:
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2382 "vm-creator.c"
	}
	_state_0:
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = _data_->self->priv->_install_media;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_->label;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = g_strdup (_data_->_tmp1_);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->base_title = _data_->_tmp2_;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->base_title;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = g_strdup (_data_->_tmp3_);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp4_;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->self->priv->_install_media;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->_tmp6_->os;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp7_ != NULL) {
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = osinfo_product_get_short_id ((OsinfoProduct*) _data_->_tmp9_);
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_tmp11_;
#line 2417 "vm-creator.c"
	} else {
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = _data_->base_title;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_tmp12_;
#line 2423 "vm-creator.c"
	}
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp5_;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->base_name = _data_->_tmp14_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = _data_->self->priv->_install_media;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = boxes_installer_media_get_live (_data_->_tmp15_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp17_) {
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = _data_->base_name;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = g_strconcat (_data_->_tmp18_, "-live", NULL);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->base_name = _data_->_tmp19_;
#line 2447 "vm-creator.c"
	}
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = _data_->base_name;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp21_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_domain_name_and_title_from_media_ready, _data_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2461 "vm-creator.c"
	_state_1:
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = NULL;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp22_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_title);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2485 "vm-creator.c"
		} else {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2489 "vm-creator.c"
		}
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2495 "vm-creator.c"
	}
	{
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->i = 2;
#line 2500 "vm-creator.c"
		{
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp23_ = TRUE;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			while (TRUE) {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp24_) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp25_ = _data_->i;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->i = _data_->_tmp25_ + 1;
#line 2514 "vm-creator.c"
				}
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp23_ = FALSE;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp28_ = boxes_vm_creator_get_connection (_data_->self);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = _data_->name;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = NULL;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = gvir_connection_find_domain_by_name (_data_->_tmp29_, _data_->_tmp30_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = _data_->_tmp31_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = _data_->_tmp32_ != NULL;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp32_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp33_) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp27_ = TRUE;
#line 2538 "vm-creator.c"
				} else {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp34_ = boxes_vm_creator_get_connection (_data_->self);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp35_ = _data_->_tmp34_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp36_ = _data_->title;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp37_ = NULL;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp37_ = gvir_connection_find_domain_by_name (_data_->_tmp35_, _data_->_tmp36_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp38_ = _data_->_tmp37_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp27_ = _data_->_tmp38_ != NULL;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp38_);
#line 2556 "vm-creator.c"
				}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp39_ = _data_->_tmp27_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp39_) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp26_ = TRUE;
#line 2564 "vm-creator.c"
				} else {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp40_ = _data_->name;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp41_ = NULL;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp41_ = gvir_storage_pool_get_volume (_data_->pool, _data_->_tmp40_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp42_ = _data_->_tmp41_;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp26_ = _data_->_tmp42_ != NULL;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp42_);
#line 2578 "vm-creator.c"
				}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp43_ = _data_->_tmp26_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp43_) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
					break;
#line 2586 "vm-creator.c"
				}
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp44_ = _data_->base_name;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp45_ = g_strconcat (_data_->_tmp44_, "-", NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp46_ = _data_->_tmp45_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp47_ = _data_->i;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp48_ = NULL;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp48_ = g_strdup_printf ("%i", _data_->_tmp47_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp49_ = _data_->_tmp48_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp50_ = g_strconcat (_data_->_tmp46_, _data_->_tmp49_, NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->name);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->name = _data_->_tmp50_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp49_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp46_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp51_ = _data_->base_title;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp52_ = g_strconcat (_data_->_tmp51_, " ", NULL);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp53_ = _data_->_tmp52_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp54_ = _data_->i;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp55_ = NULL;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp55_ = g_strdup_printf ("%i", _data_->_tmp54_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp56_ = _data_->_tmp55_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp57_ = g_strconcat (_data_->_tmp53_, _data_->_tmp56_, NULL);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->title);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_data_->title = _data_->_tmp57_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp56_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp53_);
#line 2636 "vm-creator.c"
			}
		}
	}
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->name;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2652 "vm-creator.c"
	} else {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2656 "vm-creator.c"
	}
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2674 "vm-creator.c"
	} else {
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2678 "vm-creator.c"
	}
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2684 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_data_free (gpointer _data) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateTargetVolumeData, _data_);
#line 2699 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	BoxesVMCreator* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gint64 _tmp3_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateTargetVolumeData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_vm_creator_create_target_volume);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_target_volume_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = storage;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->storage = _tmp3_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 2731 "vm-creator.c"
}


static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStorageVol* result;
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 2742 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 2752 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 2766 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_) {
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2775 "vm-creator.c"
		goto _state_0;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2779 "vm-creator.c"
		goto _state_1;
		default:
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2784 "vm-creator.c"
	}
	_state_0:
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_target_volume_ready, _data_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2793 "vm-creator.c"
	_state_1:
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp0_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2811 "vm-creator.c"
		} else {
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2815 "vm-creator.c"
		}
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2821 "vm-creator.c"
	}
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->name;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->storage;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_vm_configurator_create_volume_config (_data_->_tmp1_, _data_->_tmp2_, &_data_->_inner_error_);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp3_;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2845 "vm-creator.c"
		} else {
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2849 "vm-creator.c"
		}
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2855 "vm-creator.c"
	}
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->pool;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->config;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = gvir_storage_pool_create_volume (_data_->_tmp4_, _data_->_tmp5_, &_data_->_inner_error_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp6_;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_inner_error_ != NULL) {
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2881 "vm-creator.c"
		} else {
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2885 "vm-creator.c"
		}
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2891 "vm-creator.c"
	}
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->volume;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2903 "vm-creator.c"
	} else {
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2907 "vm-creator.c"
	}
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2923 "vm-creator.c"
	} else {
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2927 "vm-creator.c"
	}
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2933 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorGetStoragePoolData, _data_);
#line 2946 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	BoxesVMCreator* _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorGetStoragePoolData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_vm_creator_get_storage_pool);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_get_storage_pool_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 2965 "vm-creator.c"
}


static GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStoragePool* result;
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 2976 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 2986 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 3000 "vm-creator.c"
}


static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3009 "vm-creator.c"
		goto _state_0;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3013 "vm-creator.c"
		goto _state_1;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 3017 "vm-creator.c"
		goto _state_2;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 3021 "vm-creator.c"
		goto _state_3;
		default:
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3026 "vm-creator.c"
	}
	_state_0:
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = gvir_connection_find_storage_pool_by_name (_data_->_tmp1_, PACKAGE_TARNAME);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp2_;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->pool;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp3_ == NULL) {
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_vm_configurator_get_pool_config (&_data_->_inner_error_);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->config = _data_->_tmp4_;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3061 "vm-creator.c"
			} else {
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3065 "vm-creator.c"
			}
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3071 "vm-creator.c"
		}
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = boxes_vm_creator_get_connection (_data_->self);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = _data_->config;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = NULL;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = gvir_connection_create_storage_pool (_data_->_tmp6_, _data_->_tmp7_, (guint) 0, &_data_->_inner_error_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3099 "vm-creator.c"
			} else {
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3103 "vm-creator.c"
			}
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3109 "vm-creator.c"
		}
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->pool = _data_->_tmp9_;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->pool;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_async (_data_->_tmp10_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3123 "vm-creator.c"
		_state_1:
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_finish (_data_->_tmp10_, _data_->_res_, &_data_->_inner_error_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3141 "vm-creator.c"
			} else {
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3145 "vm-creator.c"
			}
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3151 "vm-creator.c"
		}
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->pool;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 2;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_async (_data_->_tmp11_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3161 "vm-creator.c"
		_state_2:
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_finish (_data_->_tmp11_, _data_->_res_, &_data_->_inner_error_);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3179 "vm-creator.c"
			} else {
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3183 "vm-creator.c"
			}
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3189 "vm-creator.c"
		}
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = _data_->pool;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_async (_data_->_tmp12_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3199 "vm-creator.c"
		_state_3:
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (_data_->_inner_error_ != NULL) {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3217 "vm-creator.c"
			} else {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3221 "vm-creator.c"
			}
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3227 "vm-creator.c"
		}
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 3231 "vm-creator.c"
	}
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->pool;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3239 "vm-creator.c"
	} else {
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3243 "vm-creator.c"
	}
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3255 "vm-creator.c"
	} else {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3259 "vm-creator.c"
	}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3265 "vm-creator.c"
}


BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3280 "vm-creator.c"
}


static void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self->priv->_install_media = _tmp1_;
#line 3297 "vm-creator.c"
}


static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self) {
	GVirConnection* result;
	BoxesApp* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_app_get_default_connection (_tmp0_);
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_;
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3318 "vm-creator.c"
}


static void boxes_value_vm_creator_init (GValue* value) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	value->data[0].v_pointer = NULL;
#line 3325 "vm-creator.c"
}


static void boxes_value_vm_creator_free_value (GValue* value) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (value->data[0].v_pointer) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (value->data[0].v_pointer);
#line 3334 "vm-creator.c"
	}
}


static void boxes_value_vm_creator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (src_value->data[0].v_pointer) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = boxes_vm_creator_ref (src_value->data[0].v_pointer);
#line 3344 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 3348 "vm-creator.c"
	}
}


static gpointer boxes_value_vm_creator_peek_pointer (const GValue* value) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 3356 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (collect_values[0].v_pointer) {
#line 3363 "vm-creator.c"
		BoxesVMCreator* object;
		object = collect_values[0].v_pointer;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3370 "vm-creator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3374 "vm-creator.c"
		}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = boxes_vm_creator_ref (object);
#line 3378 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 3382 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 3386 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesVMCreator** object_p;
	object_p = collect_values[0].v_pointer;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (!object_p) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 3397 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (!value->data[0].v_pointer) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		*object_p = NULL;
#line 3403 "vm-creator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		*object_p = value->data[0].v_pointer;
#line 3407 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		*object_p = boxes_vm_creator_ref (value->data[0].v_pointer);
#line 3411 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 3415 "vm-creator.c"
}


GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecVMCreator* spec;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return G_PARAM_SPEC (spec);
#line 3429 "vm-creator.c"
}


gpointer boxes_value_get_vm_creator (const GValue* value) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 3438 "vm-creator.c"
}


void boxes_value_set_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_ref (value->data[0].v_pointer);
#line 3458 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 3462 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 3468 "vm-creator.c"
	}
}


void boxes_value_take_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 3487 "vm-creator.c"
	} else {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 3491 "vm-creator.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 3497 "vm-creator.c"
	}
}


static void boxes_vm_creator_class_init (BoxesVMCreatorClass * klass) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->finalize = boxes_vm_creator_finalize;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_type_class_add_private (klass, sizeof (BoxesVMCreatorPrivate));
#line 3509 "vm-creator.c"
}


static void boxes_vm_creator_instance_init (BoxesVMCreator * self) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self->priv = BOXES_VM_CREATOR_GET_PRIVATE (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self->ref_count = 1;
#line 3518 "vm-creator.c"
}


static void boxes_vm_creator_finalize (BoxesVMCreator* obj) {
	BoxesVMCreator * self;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VM_CREATOR, BoxesVMCreator);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 3528 "vm-creator.c"
}


GType boxes_vm_creator_get_type (void) {
	static volatile gsize boxes_vm_creator_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vm_creator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_vm_creator_init, boxes_value_vm_creator_free_value, boxes_value_vm_creator_copy_value, boxes_value_vm_creator_peek_pointer, "p", boxes_value_vm_creator_collect_value, "p", boxes_value_vm_creator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVMCreatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vm_creator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVMCreator), 0, (GInstanceInitFunc) boxes_vm_creator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_vm_creator_type_id;
		boxes_vm_creator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesVMCreator", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_vm_creator_type_id__volatile, boxes_vm_creator_type_id);
	}
	return boxes_vm_creator_type_id__volatile;
}


gpointer boxes_vm_creator_ref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	return instance;
#line 3553 "vm-creator.c"
}


void boxes_vm_creator_unref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		BOXES_VM_CREATOR_GET_CLASS (self)->finalize (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/vm-creator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 3566 "vm-creator.c"
	}
}



